@@ -19,7 +19,7 @@ def write_json(path: str, obj: Any):
         json.dump(obj, f)
 
 
-def read_jsonlines(path: str):
+def _read_jsonlines_list(path: str):
     out = []
     with open(path) as f:
         for line in f:
@@ -27,6 +27,19 @@ def read_jsonlines(path: str):
     return out
 
 
+def _read_jsonlines_lazy(path: str):
+    with open(path) as f:
+        for line in f:
+            yield json.loads(line)
+
+
+def read_jsonlines(path: str, lazy: bool = False):
+    if lazy:
+        return _read_jsonlines_lazy(path)
+    else:
+        return _read_jsonlines_list(path)
+
+
 def write_jsonlines(path: str, elements: List[Any]):
     with open(path, "w") as f:
         for e in elements:
